REM ********************************************************************
REM Post Build file to be used during LAD SCM Project Builds.
REM Last Updated: 	7/11/2013
REM Modified by:	jacaufie
REM
REM Purpose:		This file detects the OS and invokes the local WHQL
REM			tool/INF2CAT to build the CAT files rather than from
REM			a centralized Tool share.  
REM ********************************************************************
REM 07/11/2013 - Added support for the new PRO40GB NDIS64 folder.
REM 06/17/2013 - Added support for the PRO40GB NDIS61 folder. For some reason it was never added - Jim C
REM
REM 06/05/2013 - Refactored a version 2.0.0. Removed obsolete paths as well as the pre-WHQL_BUILD copy section - Jim C
REM
REM 03/21/2013 - Added support for the NDIS64/WINBlue in CUSTOM as well as production folders - Jim C
REM
REM 03/13/2013 - Added support for the new \CUSTOM\PRO1000 and \CUSTOM\PROXGB folders - Jim C
REM
REM 03/15/2012 - Minor change for cleanup.  PostBuild.bat now handles deleting the _CAT_Sign
REM		 directory and files.  
REM 03/01/2012 - Note: Some of the new Inf2Cat OS Identifiers [8_X64,Server8_X64]
REM              can only build on Server 2008.
REM              
REM 02/28/2012 - Changed CAT file OS_Lists to be target specific in order to resolve
REM		 Issues when creating CAT files for legacy drivers.
REM
REM 02/17/2012 - Updated the three OS_LIST(s) for applicable: 
REM		 Server2008_X64,7_X64,8_X64,Server8_X64
REM
REM 12/05/2011 - Updated the Local OS detection so that it uses the OS build
REM 		 number instead of looking for an explicit string.  The previous
REM		 no longer works on Server 2003, Windows 7, Server 2008.
REM ********************************************************************

@echo off
setlocal

IF "%buildtoolsdir%" == "" SET buildtoolsdir=\\bldsrv\tools

cd _CAT_SIGN
del CAT_SIGN.LOG

goto START32

REM -------------------------------------------------------------------
:START32
REM ***************************
REM iSCSI Boot 32 - 2k3 only
REM ***************************
SET OS_LIST=Server2003_x86
set CAT_PATH=..\APPS\iSCSI\Win32
call :BUILD

REM ***************************
REM ANS - Vista/2K8/W7/W8
REM ***************************
SET OS_LIST=Vista_x86,Server2008_X86,7_X86,8_X86
set CAT_PATH=..\APPS\PROSETDX\Win32\DRIVERS
call :BUILD
SET OS_LIST=8_X86
set CAT_PATH=..\APPS\PROSETDX\Win32\DRIVERS\win8
call :BUILD

REM ***************************
REM PRO100 - XP/2K3/VISTA/2K8/W7
REM ***************************
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86
set CAT_PATH=..\PRO100\Win32\NDIS5x
set EXCEPTIONS=e100ant5.inf
call :BUILD
REM Remove the e100ant5.cat file that persists in being created despite being on the EXCEPTIONS list
del ..\PRO100\Win32\NDIS5x\e100ant5.cat /F /Q
SET OS_LIST=7_x86
set CAT_PATH=..\PRO100\Win32\NDIS62
set EXCEPTIONS=e100ant5.inf
call :BUILD
REM Remove the e100ant5.cat file that persists in being created despite being on the EXCEPTIONS list
del ..\PRO100\Win32\NDIS62\e100ant5.cat /F /Q

REM ***************************
REM PRO1000 
REM ***************************
SET OS_LIST=2000,XP_x86,Server2003_x86
set CAT_PATH=..\PRO1000\Win32\NDIS5x
call :BUILD
SET OS_LIST=Vista_x86,Server2008_X86
set CAT_PATH=..\PRO1000\Win32\NDIS61
call :BUILD
SET OS_LIST=7_X86
set CAT_PATH=..\PRO1000\Win32\NDIS62
call :BUILD
SET OS_LIST=8_X86
set CAT_PATH=..\PRO1000\Win32\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X86
SET OS_LIST=8_X86
set CAT_PATH=..\PRO1000\Win32\NDIS64
call :BUILD

REM ***************************
REM PROXGB
REM ***************************
SET OS_LIST=2000,XP_x86,Server2003_x86
set CAT_PATH=..\PROXGB\Win32\NDIS5x
call :BUILD
SET OS_LIST=Vista_x86,Server2008_X86
set CAT_PATH=..\PROXGB\Win32\NDIS61
call :BUILD
SET OS_LIST=7_X86
set CAT_PATH=..\PROXGB\Win32\NDIS62
call :BUILD
SET OS_LIST=8_X86
set CAT_PATH=..\PROXGB\Win32\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X86
SET OS_LIST=8_X86
set CAT_PATH=..\PROXGB\Win32\NDIS64
call :BUILD

REM ***************************
REM IntelAMT
REM ***************************
sET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86
set CAT_PATH=..\PLATFORM\IntelAMT\Drivers\Win32
call :BUILD

REM ***************************
REM IOATDMA
REM ***************************
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\PLATFORM\IOATDMA\Win32
call :BUILD

REM ***************************
REM Thunderbolt
REM ***************************
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\Thunderbolt\Win32\Drv
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\DebugThunderbolt\Win32\Drv
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\SimThunderbolt\Win32\Drv
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\Thunderbolt\Win32\L4000
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\DebugThunderbolt\Win32\L4000
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\SimThunderbolt\Win32\L4000
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\Thunderbolt\Win32\L5000
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\DebugThunderbolt\Win32\L5000
call :BUILD
SET OS_LIST=2000,XP_x86,Server2003_x86,Vista_x86,Server2008_X86,8_X86
set CAT_PATH=..\SimThunderbolt\Win32\L5000
call :BUILD

REM ***************************
REM CUSTOM PRO1000 
REM ***************************
SET OS_LIST=Vista_x86,Server2008_X86
set CAT_PATH=..\CUSTOM\PRO1000\Win32\NDIS61
call :BUILD
SET OS_LIST=7_X86
set CAT_PATH=..\CUSTOM\PRO1000\Win32\NDIS62
call :BUILD
SET OS_LIST=8_X86
set CAT_PATH=..\CUSTOM\PRO1000\Win32\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X86
SET OS_LIST=8_X86
set CAT_PATH=..\CUSTOM\PRO1000\Win32\NDIS64
call :BUILD

REM ***************************
REM CUSTOM PROXGB
REM ***************************
SET OS_LIST=Vista_x86,Server2008_X86
set CAT_PATH=..\CUSTOM\PROXGB\Win32\NDIS61
call :BUILD
SET OS_LIST=7_X86
set CAT_PATH=..\CUSTOM\PROXGB\Win32\NDIS62
call :BUILD
SET OS_LIST=8_X86
set CAT_PATH=..\CUSTOM\PROXGB\Win32\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X86
SET OS_LIST=8_X86
set CAT_PATH=..\CUSTOM\PROXGB\Win32\NDIS64
call :BUILD


REM -------------------------------------------------------------------
:STARTx64

REM ***************************
REM iSCSI Boot x64 - 2k3 only
REM ***************************
SET OS_LIST=Server2003_x64
set CAT_PATH=..\APPS\iSCSI\Winx64
call :BUILD

REM ***************************
REM FCoE Boot x64 - Setup
REM ***************************
SET OS_LIST=Vista_x64,Server2008_X64,Server2008R2_X64,8_X64
set CAT_PATH=..\APPS\FCOEBOOT\Winx64\Setup
call :BUILD

REM ***************************
REM ANS VISTA/2k8/W7/2K8R2/Win8
REM ***************************
SET OS_LIST=Vista_x64,Server2008_X64,7_X64,Server2008R2_X64,8_X64,Server8_X64
set CAT_PATH=..\APPS\PROSETDX\Winx64\DRIVERS
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\APPS\PROSETDX\Winx64\DRIVERS\Win8
call :BUILD

REM ***************************
REM PRO100
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64
set CAT_PATH=..\PRO100\Winx64\NDIS5x
call :BUILD
SET OS_LIST=7_X64
set CAT_PATH=..\PRO100\Winx64\NDIS62
call :BUILD

REM ***************************
REM PRO1000
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64
set CAT_PATH=..\PRO1000\Winx64\NDIS5x
call :BUILD
SET OS_LIST=Vista_x64,Server2008_X64
set CAT_PATH=..\PRO1000\Winx64\NDIS61
call :BUILD
SET OS_LIST=7_X64,Server2008R2_X64
set CAT_PATH=..\PRO1000\Winx64\NDIS62
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PRO1000\Winx64\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X64,Server6_3_X64
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PRO1000\Winx64\NDIS64
call :BUILD

REM ***************************
REM PROXGB
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64
set CAT_PATH=..\PROXGB\Winx64\NDIS5x
call :BUILD
SET OS_LIST=Vista_x64,Server2008_X64
set CAT_PATH=..\PROXGB\Winx64\NDIS61
call :BUILD
SET OS_LIST=7_X64,Server2008R2_X64
set CAT_PATH=..\PROXGB\Winx64\NDIS62
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PROXGB\Winx64\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X64,Server6_3_X64
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PROXGB\Winx64\NDIS64
call :BUILD

REM ***************************
REM PRO40GB
REM ***************************
SET OS_LIST=Vista_x64,Server2008_X64
set CAT_PATH=..\PRO40GB\Winx64\NDIS61
call :BUILD
SET OS_LIST=7_X64,Server2008R2_X64
set CAT_PATH=..\PRO40GB\Winx64\NDIS62
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PRO40GB\Winx64\NDIS63
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\PRO40GB\Winx64\NDIS64
call :BUILD

REM ***************************
REM IntelAMT
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64
set CAT_PATH=..\PLATFORM\IntelAMT\Drivers\Winx64
call :BUILD

REM ***************************
REM IOATDMA
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\PLATFORM\IOATDMA\Winx64
call :BUILD

REM ***************************
REM Thunderbolt
REM ***************************
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\DebugThunderbolt\Winx64\Drv
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\Thunderbolt\Winx64\Drv
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\SimThunderbolt\Winx64\Drv
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\DebugThunderbolt\Winx64\L4000
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\Thunderbolt\Winx64\L4000
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\SimThunderbolt\Winx64\L4000
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\DebugThunderbolt\Winx64\L5000
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\Thunderbolt\Winx64\L5000
call :BUILD
SET OS_LIST=XP_x64,Server2003_x64,Vista_x64,Server2008_X64,7_X64,8_X64,Server8_X64
set CAT_PATH=..\SimThunderbolt\Winx64\L5000
call :BUILD

REM ***************************
REM CUSTOM PRO1000
REM ***************************
SET OS_LIST=Vista_x64,Server2008_X64
set CAT_PATH=..\CUSTOM\PRO1000\Winx64\NDIS61
call :BUILD
SET OS_LIST=7_X64,Server2008R2_X64
set CAT_PATH=..\CUSTOM\PRO1000\Winx64\NDIS62
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\CUSTOM\PRO1000\Winx64\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X64,Server6_3_X64
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\CUSTOM\PRO1000\Winx64\NDIS64
call :BUILD

REM ***************************
REM CUSTOM PROXGB
REM ***************************
SET OS_LIST=Vista_x64,Server2008_X64
set CAT_PATH=..\CUSTOM\PROXGB\Winx64\NDIS61
call :BUILD
SET OS_LIST=7_X64,Server2008R2_X64
set CAT_PATH=..\CUSTOM\PROXGB\Winx64\NDIS62
call :BUILD
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\CUSTOM\PROXGB\Winx64\NDIS63
call :BUILD
REM SET OS_LIST=6_3_X64,Server6_3_X64
SET OS_LIST=8_X64,Server8_X64
set CAT_PATH=..\CUSTOM\PROXGB\Winx64\NDIS64
call :BUILD
REM >>>>>>> 1.121


REM -------------------------------------------------------------------
:START64

REM ***************************
REM ANS Server 2008
REM ***************************
SET OS_LIST=Server2008_IA64
set CAT_PATH=..\APPS\PROSETDX\Win64\DRIVERS
call :BUILD

REM ***************************
REM PRO100
REM ***************************
SET OS_LIST=Server2003_IA64
set CAT_PATH=..\PRO100\Win64
set EXCEPTIONS=e100a645.inf
call :BUILD

REM ***************************
REM PRO1000
REM ***************************
SET OS_LIST=Server2003_IA64,Server2008_IA64
set CAT_PATH=..\PRO1000\Win64
call :BUILD

REM ***************************
REM PROXGB
REM ***************************
SET OS_LIST=Server2003_IA64,Server2008_IA64
set CAT_PATH=..\PROXGB\Win64
call :BUILD

REM ***************************
REM IOATDMA
REM ***************************
SET OS_LIST=Server2003_IA64,Server2008_IA64
set CAT_PATH=..\PLATFORM\IOATDMA\Win64
call :BUILD

REM ***************************
REM CUSTOM PRO1000
REM ***************************
SET OS_LIST=Server2003_IA64,Server2008_IA64
set CAT_PATH=..\CUSTOM\PRO1000\Win64
call :BUILD

REM ***************************
REM CUSTOM PROXGB
REM ***************************
SET OS_LIST=Server2003_IA64,Server2008_IA64
set CAT_PATH=..\CUSTOM\PROXGB\Win64
call :BUILD

call :COPY_TO_WHQL
goto EXIT


REM ********************************************************************
REM Build the specified target. This behaves like a function when CALL'd
REM and returns control to the caller when the end of the file is reached.
:BUILD
REM ********************************************************************

call :BUILD2
set ORG_CAT_PATH= %CAT_PATH%

set CAT_PATH= %ORG_CAT_PATH%\NDIS5x
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS51
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS60
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS61
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS62
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS63
call :BUILD2

set CAT_PATH= %ORG_CAT_PATH%\NDIS64
call :BUILD2

goto :EOF

:BUILD2
echo . >> CAT_Sign.log
echo *************************  >> CAT_Sign.log
echo BUILD CAT FILES FOR: %CAT_PATH%  >> CAT_Sign.log
echo *************************  >> CAT_Sign.log

REM confirm the folder exists and return if it doesn't otherwise script will fail
if not exist %CAT_PATH% (
echo *** Skipping %CAT_PATH% - Folder does not exist ***
goto :EOF )

REM create the sandbox
if not exist sandbox md sandbox
del sandbox\*.* /F /Q

REM copy the driver files to the sandbox
attrib -r %CAT_PATH%\*.CAT
copy %CAT_PATH%\*.* sandbox

REM delete any exceptions
if "%EXCEPTIONS%" == "" goto END_EXCEPTIONS
echo *** Skipping exceptions: %EXCEPTIONS% >> CAT_Sign.log
cd sandbox
del %EXCEPTIONS% /F /Q
set EXCEPTIONS=
cd ..
:END_EXCEPTIONS


REM **********************************
REM ** Check current signature for   *
REM ** all CAT files in the sandbox  *
REM **********************************
cd sandbox
FOR /F "usebackq delims==" %%I IN (`dir /B *.CAT`) do call :CHECKSIGN %%~nI
cd ..
goto END_CHECKSIGN


REM **********************************
REM ** CHECKSIGN                     *
REM **********************************
:CHECKSIGN %1
set FILE=%1%
echo *** Checking signature for %FILE%.cat >> ..\CAT_Sign.log
..\SCM_ToolKit.exe verify /m /f %FILE%.cat  >> ..\CAT_Sign.log
echo *** DONE Checking signature for %FILE%.cat. LASTERROR = %ERRORLEVEL% >> ..\CAT_Sign.log
if errorlevel 1 (
echo %FILE%.cat requires signing - leave in sandbox >> ..\CAT_Sign.log
goto :EOF )

REM Found a WHQL signed CAT so don't sign this one
echo *** Skipping %FILE%.cat because it already has a Microsoft WHQL signature. ***  >> ..\CAT_Sign.log
echo *** Now Removing all .INF files that reference %FILE%.cat >> ..\Cat_Sign.log

REM *** Search all the .INF files that contain references to this CAT file and delete them ***
set CAT_FILE=%FILE%
FOR /F "usebackq delims==" %%I IN (`dir /B *.INF`) do call :Search_File %%~nI
echo Now deleting %CAT_FILE%.cat >> ..\Cat_Sign.log
del %CAT_FILE%.cat /F /Q
goto :EOF


REM **********************************************
REM ** Search_File                               *
REM ** Grep an INF File for a specific CAT file  *
REM ** Delete the INF file if string is found    *
REM **********************************************
:Search_File %1
set INF_FILE=%1%
find /I "%CAT_FILE%" %INF_FILE%.INF >> ..\Cat_Sign.log
if errorlevel 1 goto :End_Search_File
echo Found %CAT_FILE% in %INF_FILE%.inf - Deleting it>> ..\Cat_Sign.log
del %INF_FILE%.INF /F /Q
goto :EOF

:End_Search_File
echo Did not find %CAT_FILE% in %INF_FILE%.inf >> ..\Cat_Sign.log
goto :EOF

:End_CHECKSIGN
REM *********************************************************** END CHECKSIGN()


REM ***********************************************************
REM Need to determine the OS in order to properly locate the WHQL Submission install.
REM SCM builds on Server 2003 and soom Server 2008.  Ver command no longer returns an 
REM OS string for all OS's, but does return a Version #.  
REM: See http://en.wikipedia.org/wiki/Ver_(command) But verify the strings as there are some errors.
REM
REM Date: 12/5/2011 mjpaulso
REM ***********************************************************
@echo off

REM ** Detect OS and Create the new CAT files		     **
del CAT_Results.txt
REM Old: %buildtoolsdir%\inf2cat\inf2cat.exe /driver:sandbox /os:%OS_LIST% /verbose  >> CAT_Results.txt

REM Order these by the most common Build OS.  the Find calls are expensive.
REM could move this out to another calling batch file and pass in the OS.

REM Windows Server 2003
ver | find "Version 5.2.3790" > nul
if %ERRORLEVEL% == 0 goto ver_2003

REM Windows Server 2008 R2
ver | find "Version 6.1.7601" > nul
if %ERRORLEVEL% == 0 goto ver_2008

REM Windows XP.  Note Windows XP 64 Version is the same as Server 2003!
ver | find "Version 5.1.2600" > nul
if %ERRORLEVEL% == 0 goto ver_xp

REM Windows 2000
ver | find "Version 5.00.2195" > nul
if %ERRORLEVEL% == 0 goto ver_2000

REM Windows NT
ver | find "NT. Version 4.0" > nul
if %ERRORLEVEL% == 0 goto ver_nt

REM Windows 7
ver | find "Version 6.1.7600" > nul
if %ERRORLEVEL% == 0 goto ver_7

REM Windows Vista
ver| find "Version 6.0.6001" > nul
if %ERRORLEVEL% == 0 goto ver_vista

goto warnthenexit


REM changing to use correct local path on Build systems.  No longer use off of Tool share due to WHQL tool installing Inf2CAT.
:ver_7
"C:\Program Files (x86)\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
echo Windows 7 >> CAT_Results.txt 
goto POSTINF2CAT

:ver_2008
echo Windows Server 2008 >> CAT_Results.txt 
"C:\Program Files (x86)\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:ver_vista
echo Windows Vista >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:ver_2003
echo Windows Server 2003 >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:ver_xp
echo Windows XP >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:ver_2000
echo Windows 2000 >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:ver_nt
echo Windows NT >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:warnthenexit
echo Machine undetermined, using default WHQL tool location. >> CAT_Results.txt 
"C:\Program Files\Microsoft Winqual Submission Tool\inf2cat.exe" /driver:sandbox /os:%OS_LIST% /verbose >> CAT_Results.txt 
goto POSTINF2CAT

:POSTINF2CAT


if not exist CAT_Results.txt goto BUILD_FAIL_FILENOTFOUND

REM copy the results to the log file
copy /A CAT_Sign.log+CAT_Results.txt CAT_Sign.log

REM Check the result file for a failure due to INF file we deliberately deleted
Find "No installation INF found" CAT_Results.txt
if not errorlevel 1 (
echo Bailing out of CAT file creation routine due to deliberately deleted INF >> Cat_Sign.log
goto :EOF )

REM check the result file for SUCCESS/FAILURE
find "Signability test failed." CAT_Results.txt
if not errorlevel 1 goto BUILD_FAIL

REM make sure the result file has a passing log
REM some servers have permission issues and log
REM authentication errors to the log file
find "Signability test complete." CAT_Results.txt
if errorlevel 1 goto BUILD_FAIL

echo *** CAT File creation PASSED! *** >> CAT_Sign.log

REM ** Sign the new CAT files		**
SCM_ToolKit.exe signcode /f sandbox\*.cat  >> CAT_Sign.log

REM copy the new CATs back to the original folder
copy /y sandbox\*.cat %CAT_PATH% >> CAT_Sign.log
attrib +r %CAT_PATH%\*.CAT

REM return to caller
goto :EOF

REM *********************************************************** END BUILD()
:END_BUILD

:BUILD_FAIL_FILENOTFOUND
echo ***** ERROR: CAT_Results.txt not found ****** >> CAT_Sign.log

:BUILD_FAIL
set BUILD_FAILED=1
echo ****** CAT FILE CREATION FAILED: %CAT_PATH% ***** >> CAT_Sign.log
goto :EOF


:EXIT
if "%BUILD_FAILED%" == "1" goto EXIT_FAIL

REM clean up.  Postbuild.bat now handles clean up other than this one file.
REM Move this file up to the Project build directory [same level as /disk and copyfile.txt]
mv CAT_Results.txt ../..
cd ..
goto :EOF

:EXIT_FAIL
REM we failed leave the files for debugging.
cd ..


endlocal
