REM ********************************************************************
REM Last Updated: 	3/15/2012
REM Modified by:	mjpaulso
REM 
REM Purpose:    	Batch file used to create Master FLB from files residing in the LAD Project build.
REM 			See HSD: https://vthsd.intel.com/hsd/ladscm_tools/default.aspx#dcr/default.aspx?dcr_id=3746
REM
REM ********************************************************************
REM 03/15/2012 - Changed clean up steps as Postbuild.bat now removes the
REM		 _MasterFLB_PostBuild_Sandbox directory.  There is a delay on the new Server 2008
REM              build systems that is causing the directory to remain.
REM 03/02/2011 - Replaced BootUtil with BOOTUTILW64E.EXE in order to do builds on Server2008.
REM
REM ********************************************************************

REM 1. Change to the Master FLB sandbox
set MasterFLBPath=.\_MasterFLB_PostBuild_Sandbox

REM 2. Make all files read/write
cd %MasterFLBPath%
echo Deleting iv.txt >> MasterFLB.log
echo Deleting BootImg.FLB >> MasterFLB.log
del iv.txt
del BootIMG.FLB
attrib -r /S /D

REM 3. Create Master concatented FLB file
copy ComboRule.flb /b + clpload.flb /b + shared_i40e.flb /b + iscsi.flb /b + iscsi_setup.flb /b + fcoe.flb /b + BA*L*.flb /b + BA*X*.flb /b + BA*I*.flb /b + ocd.flb /b BootIMG.FLB
echo Created Master FLB file BootIMG.flb >> MasterFLB.log

REM 4. Generate image file versions embedded inside Master FLB
BOOTUTILW64E.EXE -FLBVERSIONS > iv.txt
echo Created iv.txt >> MasterFLB.log

REM 5. Checkout version database and MasterFLB from CVS repository 
set CVSROOT=:pserver:scmbuild@azusa.jf.intel.com:/home/cvsroot/ladsw
set HOME=\\bldsrv\tools\scm\scm_sql_tools
\\Bldsrv\Tools\WINCVS1.3\cvs.exe checkout -d CVS_DIR MasterFLB/database1.txt 2>>CvsGet.log 1>>Pull.log
if errorlevel 1 goto EXIT_FAIL
\\Bldsrv\Tools\WINCVS1.3\cvs.exe checkout -d CVS_DIR/image MasterFLB/image/BootIMG.FLB 2>>CvsGet.log 1>>Pull.log
if errorlevel 1 goto EXIT_FAIL
\\Bldsrv\Tools\WINCVS1.3\cvs.exe checkout -d CVS_DIR/image MasterFLB/image/iv.txt 2>>CvsGet.log 1>>Pull.log
if errorlevel 1 goto EXIT_FAIL
echo CVS files checked out >> MasterFLB.log

REM 6. Analyze database and create new MasterFLB version if actual image combination was not found in database
set CYGWIN_ROOT=\\Bldsrv\Tools\cygwin2
REM for testing set CYGWIN_ROOT=\\Gksfiler03\projects\LAD\Common\Bldsrv\tools\cygwin2 
set OLD_PATH=%PATH%
set PATH=%CYGWIN_ROOT%\bin;%CYGWIN_ROOT%\usr\bin;%PATH%

bash -x -o igncr civd.sh iv.txt CVS_DIR/database1.txt 1 2>> civd.log
if errorlevel 1 goto EXIT_FAIL
echo civd.sh finished correctly>> MasterFLB.log
call versions.cmd
echo versions.cmd finished correctly>> MasterFLB.log

REM 7. Create civd.flb file

buildflb3.exe ImageType=0x1000 "Combo Image Version Name" civd.flb %VERSION_VALUE% %VERSION_STRING%
if errorlevel 1 goto EXIT_FAIL
echo Created CIVD.flb file>> MasterFLB.log

REM 8. Checkin database changes back to CVS if necessary
\\Bldsrv\Tools\WINCVS1.3\cvs.exe ci -m "New CIVD added: %VERSION_STRING%, Project Name: %PROJ_NAME%, TIC: %TIC%" -l "CVS_DIR\database1.txt" 2>>CvsGet.log 1>>Pull.log
if errorlevel 1 goto EXIT_FAIL
echo database1.txt checked in>> MasterFLB.log

REM 9. Add newly created civd.flb file to BootIMG.flb and create iv.txt file to reflect changes to BootIMG.flb
copy BootIMG.flb /b + civd.flb /b BootIMG.flb

echo Added CIVD data to BootIMG.flb >> MasterFLB.log
BOOTUTILW64E.EXE -FLBVERSIONS > iv.txt
echo Generated iv.txt with CIVD data>> MasterFLB.log

REM 10. Modify creation time and date of resultant MasterFLB file 
if "%TIMESTAMP%" == "" goto notstp
touch -d @%TIMESTAMP% BootIMG.flb
touch -d @%TIMESTAMP% iv.txt

:notstp
set PATH=%OLD_PATH%

REM 11. Check for text in iv.txt for SUCCESS/FAILURE
find /I "Image versions in BOOTIMG.FLB" iv.txt
if errorlevel 1 goto EXIT_FAIL
echo Checked for new iv.txt >> MasterFLB.log

REM 12. Checkin BootIMG.flb and iv.txt files to CVS repository and tag with new version number
REM     This is only required if new CIVD is created

if "%NEW_VERSION%" == "" goto NO_NEW_CIVD
copy /Y iv.txt CVS_DIR\image
copy /Y BootIMG.FLB CVS_DIR\image

\\Bldsrv\Tools\WINCVS1.3\cvs.exe ci -m "MasterFLB version: %VERSION_STRING%, Project Name: %PROJ_NAME%, TIC: %TIC%" -l "CVS_DIR\image\BootIMG.FLB" 2>>CvsGet.log 1>>Pull.log
\\Bldsrv\Tools\WINCVS1.3\cvs.exe ci -m "MasterFLB version: %VERSION_STRING%, Project Name: %PROJ_NAME%, TIC: %TIC%" -l "CVS_DIR\image\iv.txt" 2>>CvsGet.log 1>>Pull.log
\\Bldsrv\Tools\WINCVS1.3\cvs.exe tag -F "%NEW_VERSION_TAG%" CVS_DIR\image\BootIMG.FLB CVS_DIR\image\iv.txt

:NO_NEW_CIVD
REM 13. Move iv.txt/FLB_Version.txt to be at \APPS\BootUtil
echo Moving iv.txt ..\APPS\BootUtil >> MasterFLB.log
echo Moving BootIMG.FLB ..\APPS\BootUtil >> MasterFLB.log
move /Y iv.txt ..\APPS\BootUtil
move /Y BootIMG.FLB ..\APPS\BootUtil
goto EXIT:

:EXIT
REM clean up
goto :EOF

:EXIT_FAIL
REM we failed so leave the files in place.
echo Failure: Master FLB Failed! >> MasterFLB.log
goto :EOF

:EOF
cd ..
endlocal
