#!/bin/bash

if (( $# != 3)); then
  printf "command line:\n\t${0##*/} iv-txt version-database-file major-version\n"
  exit 1
fi

iv_txt=$1
database_file=$2
major=$3

print_versions()
{
  # $1    - file
  # $2-$4 - version components
  # $5    - timestampt
  printf "set VERSION_STRING=%d.%d.%d\n" "$2" "$3" "$4" >> $1
  printf "set VERSION_VALUE=%02x%04x%02x\n" "$2" "$3" "$4" >> $1
  printf "set TIMESTAMP=%s\n" "$5" >> $1
  printf "set NEW_VERSION=%s\n" "$6" >> $1
  printf "set NEW_VERSION_TAG=V%d-%d-%d\n" "$2" "$3" "$4" >> $1
}
   
# versions is a "database" key, it combines all image versions in iv-txt file
# into a single line
versions=$(awk -f get-versions.awk "${iv_txt}")
# esc_versions is esentially versions with all '.' escaped to '\.' as '.' will
# match any character in regular expression
esc_versions=$(echo "${versions}" | sed -e 's/\./\\./g')
# if matched civd[0] has a major, civd[1] build and civd[2] patch level
civd=($(awk "/${esc_versions}/ { print \$2, \$3, \$4, \$5 }" $database_file))

[[ -f versions.cmd ]] || rm -f versions.cmd
  
if [[ -n "${civd[0]}" ]]; then
  # a match was found in database, print it and reuse
  print_versions versions.cmd ${civd[0]} ${civd[1]} ${civd[2]} ${civd[3]} ""
else
  # no match, bump up build
  # first find current build for $major
  civd=($(sort -n -r -k 2,2 -k 3,3 -k 4,4 "${database_file}" | awk "BEGIN { seen=0 } \$2==$major && seen==0 { print \$2, \$3, \$4 ; seen=1 }"))
  # and increment build by one
  ((civd[1]++))
  # if overflows 16 bits
  if ((civd[1] > 65535)); then
    exit 1
  fi
  # when build automatically, patch level is always 0
  ((civd[2]=0))
  # get the timestamp
  ((civd[3]=$(date +%s)))
  # append to database file
  printf "%s %d %d %d %d\n" "${versions}" ${civd[0]} ${civd[1]} ${civd[2]} ${civd[3]} >> "${database_file}"
  # and print for usage
  print_versions versions.cmd ${civd[0]} ${civd[1]} ${civd[2]} ${civd[3]} "YES"
fi
exit 0
