#!/bin/awk -f

BEGIN {
  FS="[[:blank:]]*.*[[:blank:]]+v"
}
function canonicalize_version(v) {
  split(v, a, "\\.")
  return(sprintf("%d.%d.%d", a[1], a[2], a[3]))
}
/Clp-Loader/ {
  ver["loader"] = canonicalize_version($2)
}

/40G Interface/ {
  ver["shared-40"] = canonicalize_version($2)
}

/iSCSI Setup/ {
  ver["iscsi-setup"] = canonicalize_version($2)
}

/iSCSI Option ROM/ {
  ver["iscsi"] = canonicalize_version($2)
}

/FCoE/ {
  ver["fcoe"] = canonicalize_version($2)
}

/FE/ {
  ver["pxe-fe"] = canonicalize_version($2)
}

/GE/ {
  ver["pxe-ge"] = canonicalize_version($2)
}

/XG/ {
  ver["pxe-xg"] = canonicalize_version($2)
}

/XE/ {
  ver["pxe-xe"] = canonicalize_version($2)
}

/I40E/ {
  ver["pxe-i40e"] = canonicalize_version($2)
}

/UEFI x64 PCI gigabit/ {
  ver["efi-x64-pci"] = canonicalize_version($2)
}

/UEFI x64 PCI-E gigabit/ {
  ver["efi-x64-pcie"] = canonicalize_version($2)
}

/UEFI x64 10 gigabit/ {
  ver["efi-x64-xg"] = canonicalize_version($2)
}

/UEFI x64 40 gigabit/ {
  ver["efi-x64-i40e"] = canonicalize_version($2)
}

/UEFI IA64 PCI gigabit/ {
  ver["efi-ia64-pci"] = canonicalize_version($2)
}

/UEFI IA64 PCI-E gigabit/ {
  ver["efi-ia64-pcie"] = canonicalize_version($2)
}

/UEFI IA64 10 gigabit/ {
  ver["efi-ia64-xg"] = canonicalize_version($2)
}

/UEFI IA64 40 gigabit/ {
  ver["efi-ia64-i40e"] = canonicalize_version($2)
}

/OCD/ {
  ver["ocd"] = canonicalize_version($2)
}

END {
  printf "%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s:%s\n",
    ver["loader"], ver["shared-40"],
    ver["iscsi-setup"], ver["iscsi"],
    ver["fcoe"],
    ver["pxe-fe"], ver["pxe-ge"], ver["pxe-xg"], ver["pxe-xe"], ver["pxe-i40e"],
    ver["efi-x64-pci"], ver["efi-x64-pcie"], ver["efi-x64-xg"], ver["efi-x64-i40e"],
    ver["efi-ia64-pci"], ver["efi-ia64-pcie"], ver["efi-ia64-xg"], ver["efi-ia64-i40e"],
    ver["ocd"]
}
